==> persistence-commons-infinispan-1.0.0.Final-sources.jar: org/kie/kogito/persistence/infinispan/cache/InfinispanCacheShutdownObserver.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.kogito.persistence.infinispan.cache;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.event.Observes;
import javax.inject.Inject;

import io.quarkus.runtime.ShutdownEvent;
import org.eclipse.microprofile.config.inject.ConfigProperty;
import org.kie.kogito.persistence.api.StorageService;

import static org.kie.kogito.persistence.api.factory.Constants.PERSISTENCE_TYPE_PROPERTY;
import static org.kie.kogito.persistence.infinispan.Constants.INFINISPAN_STORAGE;

@ApplicationScoped
public class InfinispanCacheShutdownObserver {

    @ConfigProperty(name = PERSISTENCE_TYPE_PROPERTY)
    String storageType;

    @Inject
    StorageService cacheService;

    public void stop(@Observes ShutdownEvent event) {
        if (INFINISPAN_STORAGE.equals(storageType) && cacheService instanceof InfinispanCacheManager) {
            ((InfinispanCacheManager) cacheService).destroy();
        }
    }
}

==> persistence-commons-infinispan-1.24.0.Final-sources.jar: org/kie/kogito/persistence/infinispan/cache/InfinispanCacheShutdownObserver.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.kogito.persistence.infinispan.cache;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.event.Observes;
import javax.inject.Inject;

import org.eclipse.microprofile.config.inject.ConfigProperty;
import org.kie.kogito.persistence.api.StorageService;

import io.quarkus.runtime.ShutdownEvent;

import static org.kie.kogito.persistence.api.factory.Constants.PERSISTENCE_TYPE_PROPERTY;
import static org.kie.kogito.persistence.infinispan.Constants.INFINISPAN_STORAGE;

@ApplicationScoped
public class InfinispanCacheShutdownObserver {

    @ConfigProperty(name = PERSISTENCE_TYPE_PROPERTY)
    String storageType;

    @Inject
    StorageService cacheService;

    public void stop(@Observes ShutdownEvent event) {
        if (INFINISPAN_STORAGE.equals(storageType) && cacheService instanceof InfinispanStorageService) {
            ((InfinispanStorageService) cacheService).destroy();
        }
    }
}
